﻿using System.Linq;
using PagingWithRadioButtons.ViewModels;
using Syncfusion.ListView.XForms;
using Syncfusion.SfDataGrid.XForms.DataPager;
using Xamarin.Forms;

namespace PagingWithRadioButtons.Behavior
{
	public class SfListViewPagingBehavior : Behavior<ContentPage>
	{
		private SfListView _listView;
		private SfDataPager _dataPager;
		private IssuePagingViewModel _issueViewModel;

		protected override void OnAttachedTo(ContentPage bindable)
		{
			_listView = bindable.FindByName<Syncfusion.ListView.XForms.SfListView>("listView");
			_dataPager = bindable.FindByName<SfDataPager>("dataPager");
			_issueViewModel = new IssuePagingViewModel();
			_listView.BindingContext = _issueViewModel;
			_dataPager.NumericButtonCount = _issueViewModel.Items.Count > 3 ? 3 : _issueViewModel.Items.Count;
			_dataPager.PageCount = _issueViewModel.Items.Count;
			_dataPager.Source = _issueViewModel.Items;
			_dataPager.OnDemandLoading += OnDemandLoading;
			base.OnAttachedTo(bindable);
		}

		private void OnDemandLoading(object sender, OnDemandLoadingEventArgs e)
		{
			var source = _issueViewModel.Items.Skip(e.StartIndex).Take(e.PageSize);
			_listView.ItemsSource = source.AsEnumerable();
		}


		protected override void OnDetachingFrom(ContentPage bindable)
		{
			_listView = null;
			_issueViewModel = null;
			_dataPager = null;
			base.OnDetachingFrom(bindable);
		}
	}
}